@@ -35,4 +35,13 @@ test.diploid.locus <- function() {
 	checkEquals( loc3[1], "A" )
 	loc3[2] <- "T"
 	checkEquals( as.character(loc3), "A:T" )
+}
+
+test.ops.locus <- function() { 
+	loc1 <- Locus( 1:2 )
+	loc2 <- Locus( 1:2 )
+	loc3 <- Locus( c("A","A") )
+
+	checkTrue( loc1==loc2 )
+	checkTrue( loc1!=loc3 )
 }
\ No newline at end of file
